summaryrefslogtreecommitdiffstats
path: root/examples/movies/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/movies/main.cpp')
-rw-r--r--examples/movies/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/movies/main.cpp b/examples/movies/main.cpp
index 5aaea565..abb1cf0b 100644
--- a/examples/movies/main.cpp
+++ b/examples/movies/main.cpp
@@ -225,7 +225,7 @@ public:
public slots:
void startMovie(const TQString& filename);
// TQDialog's method - normally closes the file dialog.
// We want it left open, and we want Cancel to tquit everything.
void done( int r );
};
@@ -251,7 +251,7 @@ void MovieStarter::startMovie(const TQString& filename)
void MovieStarter::done( int r )
{
if (r != Accepted)
- qApp->tquit(); // end on Cancel
+ qApp->quit(); // end on Cancel
setResult( r );
// And don't hide.
@@ -276,7 +276,7 @@ int main(int argc, char **argv)
(void)new MovieScreen(argv[arg], TQMovie(argv[arg]), 0, 0,
TQt::WDestructiveClose);
}
- TQObject::connect(qApp, SIGNAL(lastWindowClosed()), qApp, SLOT(tquit()));
+ TQObject::connect(qApp, SIGNAL(lastWindowClosed()), qApp, SLOT(quit()));
} else {
// "GUI" mode - open a chooser for movies
//
@@ -225,7 +225,7 @@ public:
void startMovie(const TQString& filename);
// TQDialog's method - normally closes the file dialog.
- // We want it left open, and we want Cancel to tquit everything.
+ // We want it left open, and we want Cancel to quit everything.
void done( int r );
};